pub struct TimeStep {
pub unix_time_ms: u64,
pub gps_time_ms: u64,
}Expand description
This is a struct for our timesteps NOTE: correlator timesteps use unix time, voltage timesteps use gpstime, but we convert the two depending on what we are given
Fields
unix_time_ms: u64UNIX time (in milliseconds to avoid floating point inaccuracy)
gps_time_ms: u64gps time (in milliseconds)